# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wandb/proto/wandb_internal.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from wandb.proto import wandb_telemetry_pb2 as wandb_dot_proto_dot_wandb__telemetry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='wandb/proto/wandb_internal.proto',
  package='wandb_internal',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n wandb/proto/wandb_internal.proto\x12\x0ewandb_internal\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!wandb/proto/wandb_telemetry.proto\"\x85\x07\n\x06Record\x12\x0b\n\x03num\x18\x01 \x01(\x03\x12\x30\n\x07history\x18\x02 \x01(\x0b\x32\x1d.wandb_internal.HistoryRecordH\x00\x12\x30\n\x07summary\x18\x03 \x01(\x0b\x32\x1d.wandb_internal.SummaryRecordH\x00\x12.\n\x06output\x18\x04 \x01(\x0b\x32\x1c.wandb_internal.OutputRecordH\x00\x12.\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\x1c.wandb_internal.ConfigRecordH\x00\x12,\n\x05\x66iles\x18\x06 \x01(\x0b\x32\x1b.wandb_internal.FilesRecordH\x00\x12,\n\x05stats\x18\x07 \x01(\x0b\x32\x1b.wandb_internal.StatsRecordH\x00\x12\x32\n\x08\x61rtifact\x18\x08 \x01(\x0b\x32\x1e.wandb_internal.ArtifactRecordH\x00\x12,\n\x08tbrecord\x18\t \x01(\x0b\x32\x18.wandb_internal.TBRecordH\x00\x12,\n\x05\x61lert\x18\n \x01(\x0b\x32\x1b.wandb_internal.AlertRecordH\x00\x12\x34\n\ttelemetry\x18\x0b \x01(\x0b\x32\x1f.wandb_internal.TelemetryRecordH\x00\x12.\n\x06metric\x18\x0c \x01(\x0b\x32\x1c.wandb_internal.MetricRecordH\x00\x12(\n\x03run\x18\x11 \x01(\x0b\x32\x19.wandb_internal.RunRecordH\x00\x12-\n\x04\x65xit\x18\x12 \x01(\x0b\x32\x1d.wandb_internal.RunExitRecordH\x00\x12,\n\x05\x66inal\x18\x14 \x01(\x0b\x32\x1b.wandb_internal.FinalRecordH\x00\x12.\n\x06header\x18\x15 \x01(\x0b\x32\x1c.wandb_internal.HeaderRecordH\x00\x12.\n\x06\x66ooter\x18\x16 \x01(\x0b\x32\x1c.wandb_internal.FooterRecordH\x00\x12*\n\x07request\x18\x64 \x01(\x0b\x32\x17.wandb_internal.RequestH\x00\x12(\n\x07\x63ontrol\x18\x10 \x01(\x0b\x32\x17.wandb_internal.Control\x12\x0c\n\x04uuid\x18\x13 \x01(\tB\r\n\x0brecord_type\"*\n\x07\x43ontrol\x12\x10\n\x08req_resp\x18\x01 \x01(\x08\x12\r\n\x05local\x18\x02 \x01(\x08\"\x9c\x03\n\x06Result\x12\x35\n\nrun_result\x18\x11 \x01(\x0b\x32\x1f.wandb_internal.RunUpdateResultH\x00\x12\x34\n\x0b\x65xit_result\x18\x12 \x01(\x0b\x32\x1d.wandb_internal.RunExitResultH\x00\x12\x33\n\nlog_result\x18\x14 \x01(\x0b\x32\x1d.wandb_internal.HistoryResultH\x00\x12\x37\n\x0esummary_result\x18\x15 \x01(\x0b\x32\x1d.wandb_internal.SummaryResultH\x00\x12\x35\n\routput_result\x18\x16 \x01(\x0b\x32\x1c.wandb_internal.OutputResultH\x00\x12\x35\n\rconfig_result\x18\x17 \x01(\x0b\x32\x1c.wandb_internal.ConfigResultH\x00\x12,\n\x08response\x18\x64 \x01(\x0b\x32\x18.wandb_internal.ResponseH\x00\x12\x0c\n\x04uuid\x18\x18 \x01(\tB\r\n\x0bresult_type\"\r\n\x0b\x46inalRecord\"\x0e\n\x0cHeaderRecord\"\x0e\n\x0c\x46ooterRecord\"\xe4\x03\n\tRunRecord\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12,\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x1c.wandb_internal.ConfigRecord\x12.\n\x07summary\x18\x05 \x01(\x0b\x32\x1d.wandb_internal.SummaryRecord\x12\x11\n\trun_group\x18\x06 \x01(\t\x12\x10\n\x08job_type\x18\x07 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x08 \x01(\t\x12\r\n\x05notes\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12\x30\n\x08settings\x18\x0b \x01(\x0b\x32\x1e.wandb_internal.SettingsRecord\x12\x10\n\x08sweep_id\x18\x0c \x01(\t\x12\x0c\n\x04host\x18\r \x01(\t\x12\x15\n\rstarting_step\x18\x0e \x01(\x03\x12\x12\n\nstorage_id\x18\x10 \x01(\t\x12.\n\nstart_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07resumed\x18\x12 \x01(\x08\x12\x32\n\ttelemetry\x18\x13 \x01(\x0b\x32\x1f.wandb_internal.TelemetryRecord\"c\n\x0fRunUpdateResult\x12&\n\x03run\x18\x01 \x01(\x0b\x32\x19.wandb_internal.RunRecord\x12(\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x19.wandb_internal.ErrorInfo\"\xa1\x01\n\tErrorInfo\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x31\n\x04\x63ode\x18\x02 \x01(\x0e\x32#.wandb_internal.ErrorInfo.ErrorCode\"P\n\tErrorCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07INVALID\x10\x01\x12\x0e\n\nPERMISSION\x10\x02\x12\x0b\n\x07NETWORK\x10\x03\x12\x0c\n\x08INTERNAL\x10\x04\"\"\n\rRunExitRecord\x12\x11\n\texit_code\x18\x01 \x01(\x05\"\x0f\n\rRunExitResult\"<\n\x0eSettingsRecord\x12*\n\x04item\x18\x01 \x03(\x0b\x32\x1c.wandb_internal.SettingsItem\"/\n\x0cSettingsItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_json\x18\x10 \x01(\t\"\x1a\n\x0bHistoryStep\x12\x0b\n\x03num\x18\x01 \x01(\x03\"e\n\rHistoryRecord\x12)\n\x04item\x18\x01 \x03(\x0b\x32\x1b.wandb_internal.HistoryItem\x12)\n\x04step\x18\x02 \x01(\x0b\x32\x1b.wandb_internal.HistoryStep\"B\n\x0bHistoryItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nnested_key\x18\x02 \x03(\t\x12\x12\n\nvalue_json\x18\x10 \x01(\t\"\x0f\n\rHistoryResult\"\xaf\x01\n\x0cOutputRecord\x12<\n\x0boutput_type\x18\x01 \x01(\x0e\x32\'.wandb_internal.OutputRecord.OutputType\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04line\x18\x03 \x01(\t\"$\n\nOutputType\x12\n\n\x06STDERR\x10\x00\x12\n\n\x06STDOUT\x10\x01\"\x0e\n\x0cOutputResult\"\xeb\x02\n\x0cMetricRecord\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tglob_name\x18\x02 \x01(\t\x12\x13\n\x0bstep_metric\x18\x04 \x01(\t\x12\x19\n\x11step_metric_index\x18\x05 \x01(\x05\x12.\n\x07options\x18\x06 \x01(\x0b\x32\x1d.wandb_internal.MetricOptions\x12.\n\x07summary\x18\x07 \x01(\x0b\x32\x1d.wandb_internal.MetricSummary\x12\x35\n\x04goal\x18\x08 \x01(\x0e\x32\'.wandb_internal.MetricRecord.MetricGoal\x12/\n\x08_control\x18\t \x01(\x0b\x32\x1d.wandb_internal.MetricControl\"B\n\nMetricGoal\x12\x0e\n\nGOAL_UNSET\x10\x00\x12\x11\n\rGOAL_MINIMIZE\x10\x01\x12\x11\n\rGOAL_MAXIMIZE\x10\x02\"C\n\rMetricOptions\x12\x11\n\tstep_sync\x18\x01 \x01(\x08\x12\x0e\n\x06hidden\x18\x02 \x01(\x08\x12\x0f\n\x07\x64\x65\x66ined\x18\x03 \x01(\x08\"\"\n\rMetricControl\x12\x11\n\toverwrite\x18\x01 \x01(\x08\"o\n\rMetricSummary\x12\x0b\n\x03min\x18\x01 \x01(\x08\x12\x0b\n\x03max\x18\x02 \x01(\x08\x12\x0c\n\x04mean\x18\x03 \x01(\x08\x12\x0c\n\x04\x62\x65st\x18\x04 \x01(\x08\x12\x0c\n\x04last\x18\x05 \x01(\x08\x12\x0c\n\x04none\x18\x06 \x01(\x08\x12\x0c\n\x04\x63opy\x18\x07 \x01(\x08\"f\n\x0c\x43onfigRecord\x12*\n\x06update\x18\x01 \x03(\x0b\x32\x1a.wandb_internal.ConfigItem\x12*\n\x06remove\x18\x02 \x03(\x0b\x32\x1a.wandb_internal.ConfigItem\"A\n\nConfigItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nnested_key\x18\x02 \x03(\t\x12\x12\n\nvalue_json\x18\x10 \x01(\t\"\x0e\n\x0c\x43onfigResult\"i\n\rSummaryRecord\x12+\n\x06update\x18\x01 \x03(\x0b\x32\x1b.wandb_internal.SummaryItem\x12+\n\x06remove\x18\x02 \x03(\x0b\x32\x1b.wandb_internal.SummaryItem\"B\n\x0bSummaryItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nnested_key\x18\x02 \x03(\t\x12\x12\n\nvalue_json\x18\x10 \x01(\t\"\x0f\n\rSummaryResult\"7\n\x0b\x46ilesRecord\x12(\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x19.wandb_internal.FilesItem\"\x90\x01\n\tFilesItem\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x34\n\x06policy\x18\x02 \x01(\x0e\x32$.wandb_internal.FilesItem.PolicyType\x12\x15\n\rexternal_path\x18\x10 \x01(\t\"(\n\nPolicyType\x12\x07\n\x03NOW\x10\x00\x12\x07\n\x03\x45ND\x10\x01\x12\x08\n\x04LIVE\x10\x02\"\xb9\x01\n\x0bStatsRecord\x12\x39\n\nstats_type\x18\x01 \x01(\x0e\x32%.wandb_internal.StatsRecord.StatsType\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x04item\x18\x03 \x03(\x0b\x32\x19.wandb_internal.StatsItem\"\x17\n\tStatsType\x12\n\n\x06SYSTEM\x10\x00\",\n\tStatsItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_json\x18\x10 \x01(\t\"\xce\x02\n\x0e\x41rtifactRecord\x12\x0e\n\x06run_id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12\x0e\n\x06\x65ntity\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06\x64igest\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x10\n\x08metadata\x18\x08 \x01(\t\x12\x14\n\x0cuser_created\x18\t \x01(\x08\x12\x18\n\x10use_after_commit\x18\n \x01(\x08\x12\x0f\n\x07\x61liases\x18\x0b \x03(\t\x12\x32\n\x08manifest\x18\x0c \x01(\x0b\x32 .wandb_internal.ArtifactManifest\x12\x16\n\x0e\x64istributed_id\x18\r \x01(\t\x12\x10\n\x08\x66inalize\x18\x0e \x01(\x08\x12\x19\n\x11incremental_beta1\x18\x64 \x01(\x08\"\xbc\x01\n\x10\x41rtifactManifest\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x16\n\x0estorage_policy\x18\x02 \x01(\t\x12\x46\n\x15storage_policy_config\x18\x03 \x03(\x0b\x32\'.wandb_internal.StoragePolicyConfigItem\x12\x37\n\x08\x63ontents\x18\x04 \x03(\x0b\x32%.wandb_internal.ArtifactManifestEntry\"\xbb\x01\n\x15\x41rtifactManifestEntry\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\x12\x0b\n\x03ref\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12\x10\n\x08mimetype\x18\x05 \x01(\t\x12\x12\n\nlocal_path\x18\x06 \x01(\t\x12\x19\n\x11\x62irth_artifact_id\x18\x07 \x01(\t\x12(\n\x05\x65xtra\x18\x10 \x03(\x0b\x32\x19.wandb_internal.ExtraItem\",\n\tExtraItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_json\x18\x02 \x01(\t\":\n\x17StoragePolicyConfigItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nvalue_json\x18\x02 \x01(\t\";\n\x08TBRecord\x12\x0f\n\x07log_dir\x18\x01 \x01(\t\x12\x0c\n\x04save\x18\x02 \x01(\x08\x12\x10\n\x08root_dir\x18\x03 \x01(\t\"P\n\x0b\x41lertRecord\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12\x15\n\rwait_duration\x18\x04 \x01(\x03\"\xa3\x06\n\x07Request\x12\x38\n\x0bstop_status\x18\x01 \x01(\x0b\x32!.wandb_internal.StopStatusRequestH\x00\x12>\n\x0enetwork_status\x18\x02 \x01(\x0b\x32$.wandb_internal.NetworkStatusRequestH\x00\x12-\n\x05\x64\x65\x66\x65r\x18\x03 \x01(\x0b\x32\x1c.wandb_internal.DeferRequestH\x00\x12\x38\n\x0bget_summary\x18\x04 \x01(\x0b\x32!.wandb_internal.GetSummaryRequestH\x00\x12-\n\x05login\x18\x05 \x01(\x0b\x32\x1c.wandb_internal.LoginRequestH\x00\x12-\n\x05pause\x18\x06 \x01(\x0b\x32\x1c.wandb_internal.PauseRequestH\x00\x12/\n\x06resume\x18\x07 \x01(\x0b\x32\x1d.wandb_internal.ResumeRequestH\x00\x12\x34\n\tpoll_exit\x18\x08 \x01(\x0b\x32\x1f.wandb_internal.PollExitRequestH\x00\x12@\n\x0fsampled_history\x18\t \x01(\x0b\x32%.wandb_internal.SampledHistoryRequestH\x00\x12\x34\n\trun_start\x18\x0b \x01(\x0b\x32\x1f.wandb_internal.RunStartRequestH\x00\x12<\n\rcheck_version\x18\x0c \x01(\x0b\x32#.wandb_internal.CheckVersionRequestH\x00\x12:\n\x0clog_artifact\x18\r \x01(\x0b\x32\".wandb_internal.LogArtifactRequestH\x00\x12\x33\n\x08shutdown\x18@ \x01(\x0b\x32\x1f.wandb_internal.ShutdownRequestH\x00\x12\x39\n\x0btest_inject\x18\xe8\x07 \x01(\x0b\x32!.wandb_internal.TestInjectRequestH\x00\x42\x0e\n\x0crequest_type\"\x84\x06\n\x08Response\x12\x42\n\x14stop_status_response\x18\x13 \x01(\x0b\x32\".wandb_internal.StopStatusResponseH\x00\x12H\n\x17network_status_response\x18\x14 \x01(\x0b\x32%.wandb_internal.NetworkStatusResponseH\x00\x12\x37\n\x0elogin_response\x18\x18 \x01(\x0b\x32\x1d.wandb_internal.LoginResponseH\x00\x12\x42\n\x14get_summary_response\x18\x19 \x01(\x0b\x32\".wandb_internal.GetSummaryResponseH\x00\x12>\n\x12poll_exit_response\x18\x1a \x01(\x0b\x32 .wandb_internal.PollExitResponseH\x00\x12J\n\x18sampled_history_response\x18\x1b \x01(\x0b\x32&.wandb_internal.SampledHistoryResponseH\x00\x12>\n\x12run_start_response\x18\x1c \x01(\x0b\x32 .wandb_internal.RunStartResponseH\x00\x12\x46\n\x16\x63heck_version_response\x18\x1d \x01(\x0b\x32$.wandb_internal.CheckVersionResponseH\x00\x12\x44\n\x15log_artifact_response\x18\x1e \x01(\x0b\x32#.wandb_internal.LogArtifactResponseH\x00\x12=\n\x11shutdown_response\x18@ \x01(\x0b\x32 .wandb_internal.ShutdownResponseH\x00\x12\x43\n\x14test_inject_response\x18\xe8\x07 \x01(\x0b\x32\".wandb_internal.TestInjectResponseH\x00\x42\x0f\n\rresponse_type\"\xd3\x01\n\x0c\x44\x65\x66\x65rRequest\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32\'.wandb_internal.DeferRequest.DeferState\"\x8a\x01\n\nDeferState\x12\t\n\x05\x42\x45GIN\x10\x00\x12\x0f\n\x0b\x46LUSH_STATS\x10\x01\x12\x0c\n\x08\x46LUSH_TB\x10\x02\x12\r\n\tFLUSH_SUM\x10\x03\x12\r\n\tFLUSH_DIR\x10\x04\x12\x0c\n\x08\x46LUSH_FP\x10\x05\x12\x0c\n\x08\x46LUSH_FS\x10\x06\x12\x0f\n\x0b\x46LUSH_FINAL\x10\x07\x12\x07\n\x03\x45ND\x10\x08\"\x0e\n\x0cPauseRequest\"\x0f\n\rResumeRequest\"\x1f\n\x0cLoginRequest\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\"&\n\rLoginResponse\x12\x15\n\ractive_entity\x18\x01 \x01(\t\"\x13\n\x11GetSummaryRequest\"?\n\x12GetSummaryResponse\x12)\n\x04item\x18\x01 \x03(\x0b\x32\x1b.wandb_internal.SummaryItem\"\x13\n\x11StopStatusRequest\"-\n\x12StopStatusResponse\x12\x17\n\x0frun_should_stop\x18\x01 \x01(\x08\"\x16\n\x14NetworkStatusRequest\"P\n\x15NetworkStatusResponse\x12\x37\n\x11network_responses\x18\x01 \x03(\x0b\x32\x1c.wandb_internal.HttpResponse\"D\n\x0cHttpResponse\x12\x18\n\x10http_status_code\x18\x01 \x01(\x05\x12\x1a\n\x12http_response_text\x18\x02 \x01(\t\"\x11\n\x0fPollExitRequest\"\xbc\x01\n\x10PollExitResponse\x12\x0c\n\x04\x64one\x18\x01 \x01(\x08\x12\x32\n\x0b\x65xit_result\x18\x02 \x01(\x0b\x32\x1d.wandb_internal.RunExitResult\x12/\n\x0b\x66ile_counts\x18\x03 \x01(\x0b\x32\x1a.wandb_internal.FileCounts\x12\x35\n\x0cpusher_stats\x18\x04 \x01(\x0b\x32\x1f.wandb_internal.FilePusherStats\"c\n\nFileCounts\x12\x13\n\x0bwandb_count\x18\x01 \x01(\x05\x12\x13\n\x0bmedia_count\x18\x02 \x01(\x05\x12\x16\n\x0e\x61rtifact_count\x18\x03 \x01(\x05\x12\x13\n\x0bother_count\x18\x04 \x01(\x05\"U\n\x0f\x46ilePusherStats\x12\x16\n\x0euploaded_bytes\x18\x01 \x01(\x03\x12\x13\n\x0btotal_bytes\x18\x02 \x01(\x03\x12\x15\n\rdeduped_bytes\x18\x03 \x01(\x03\"\x11\n\x0fShutdownRequest\"\x12\n\x10ShutdownResponse\"\xa7\x02\n\x11TestInjectRequest\x12\x13\n\x0bhandler_exc\x18\x01 \x01(\x08\x12\x14\n\x0chandler_exit\x18\x02 \x01(\x08\x12\x15\n\rhandler_abort\x18\x03 \x01(\x08\x12\x12\n\nsender_exc\x18\x04 \x01(\x08\x12\x13\n\x0bsender_exit\x18\x05 \x01(\x08\x12\x14\n\x0csender_abort\x18\x06 \x01(\x08\x12\x0f\n\x07req_exc\x18\x07 \x01(\x08\x12\x10\n\x08req_exit\x18\x08 \x01(\x08\x12\x11\n\treq_abort\x18\t \x01(\x08\x12\x10\n\x08resp_exc\x18\n \x01(\x08\x12\x11\n\tresp_exit\x18\x0b \x01(\x08\x12\x12\n\nresp_abort\x18\x0c \x01(\x08\x12\x10\n\x08msg_drop\x18\r \x01(\x08\x12\x10\n\x08msg_hang\x18\x0e \x01(\x08\"\x14\n\x12TestInjectResponse\"\x17\n\x15SampledHistoryRequest\"_\n\x12SampledHistoryItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nnested_key\x18\x02 \x03(\t\x12\x14\n\x0cvalues_float\x18\x03 \x03(\x02\x12\x12\n\nvalues_int\x18\x04 \x03(\x03\"J\n\x16SampledHistoryResponse\x12\x30\n\x04item\x18\x01 \x03(\x0b\x32\".wandb_internal.SampledHistoryItem\"9\n\x0fRunStartRequest\x12&\n\x03run\x18\x01 \x01(\x0b\x32\x19.wandb_internal.RunRecord\"\x12\n\x10RunStartResponse\".\n\x13\x43heckVersionRequest\x12\x17\n\x0f\x63urrent_version\x18\x01 \x01(\t\"]\n\x14\x43heckVersionResponse\x12\x17\n\x0fupgrade_message\x18\x01 \x01(\t\x12\x14\n\x0cyank_message\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65lete_message\x18\x03 \x01(\t\"F\n\x12LogArtifactRequest\x12\x30\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32\x1e.wandb_internal.ArtifactRecord\"A\n\x13LogArtifactResponse\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\tb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,wandb_dot_proto_dot_wandb__telemetry__pb2.DESCRIPTOR,])



_ERRORINFO_ERRORCODE = _descriptor.EnumDescriptor(
  name='ErrorCode',
  full_name='wandb_internal.ErrorInfo.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2200,
  serialized_end=2280,
)
_sym_db.RegisterEnumDescriptor(_ERRORINFO_ERRORCODE)

_OUTPUTRECORD_OUTPUTTYPE = _descriptor.EnumDescriptor(
  name='OutputType',
  full_name='wandb_internal.OutputRecord.OutputType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STDERR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STDOUT', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2802,
  serialized_end=2838,
)
_sym_db.RegisterEnumDescriptor(_OUTPUTRECORD_OUTPUTTYPE)

_METRICRECORD_METRICGOAL = _descriptor.EnumDescriptor(
  name='MetricGoal',
  full_name='wandb_internal.MetricRecord.MetricGoal',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GOAL_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOAL_MINIMIZE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GOAL_MAXIMIZE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3154,
  serialized_end=3220,
)
_sym_db.RegisterEnumDescriptor(_METRICRECORD_METRICGOAL)

_FILESITEM_POLICYTYPE = _descriptor.EnumDescriptor(
  name='PolicyType',
  full_name='wandb_internal.FilesItem.PolicyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIVE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3981,
  serialized_end=4021,
)
_sym_db.RegisterEnumDescriptor(_FILESITEM_POLICYTYPE)

_STATSRECORD_STATSTYPE = _descriptor.EnumDescriptor(
  name='StatsType',
  full_name='wandb_internal.StatsRecord.StatsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4186,
  serialized_end=4209,
)
_sym_db.RegisterEnumDescriptor(_STATSRECORD_STATSTYPE)

_DEFERREQUEST_DEFERSTATE = _descriptor.EnumDescriptor(
  name='DeferState',
  full_name='wandb_internal.DeferRequest.DeferState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BEGIN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLUSH_STATS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLUSH_TB', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLUSH_SUM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLUSH_DIR', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLUSH_FP', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLUSH_FS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLUSH_FINAL', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END', index=8, number=8,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6879,
  serialized_end=7017,
)
_sym_db.RegisterEnumDescriptor(_DEFERREQUEST_DEFERSTATE)


_RECORD = _descriptor.Descriptor(
  name='Record',
  full_name='wandb_internal.Record',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='wandb_internal.Record.num', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='history', full_name='wandb_internal.Record.history', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='wandb_internal.Record.summary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='wandb_internal.Record.output', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='wandb_internal.Record.config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='files', full_name='wandb_internal.Record.files', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='wandb_internal.Record.stats', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact', full_name='wandb_internal.Record.artifact', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tbrecord', full_name='wandb_internal.Record.tbrecord', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alert', full_name='wandb_internal.Record.alert', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='wandb_internal.Record.telemetry', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metric', full_name='wandb_internal.Record.metric', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run', full_name='wandb_internal.Record.run', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit', full_name='wandb_internal.Record.exit', index=13,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final', full_name='wandb_internal.Record.final', index=14,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='wandb_internal.Record.header', index=15,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer', full_name='wandb_internal.Record.footer', index=16,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='wandb_internal.Record.request', index=17,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='control', full_name='wandb_internal.Record.control', index=18,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='wandb_internal.Record.uuid', index=19,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='record_type', full_name='wandb_internal.Record.record_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=121,
  serialized_end=1022,
)


_CONTROL = _descriptor.Descriptor(
  name='Control',
  full_name='wandb_internal.Control',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_resp', full_name='wandb_internal.Control.req_resp', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local', full_name='wandb_internal.Control.local', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1024,
  serialized_end=1066,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='wandb_internal.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_result', full_name='wandb_internal.Result.run_result', index=0,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_result', full_name='wandb_internal.Result.exit_result', index=1,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_result', full_name='wandb_internal.Result.log_result', index=2,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary_result', full_name='wandb_internal.Result.summary_result', index=3,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_result', full_name='wandb_internal.Result.output_result', index=4,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config_result', full_name='wandb_internal.Result.config_result', index=5,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='wandb_internal.Result.response', index=6,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='wandb_internal.Result.uuid', index=7,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result_type', full_name='wandb_internal.Result.result_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1069,
  serialized_end=1481,
)


_FINALRECORD = _descriptor.Descriptor(
  name='FinalRecord',
  full_name='wandb_internal.FinalRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1483,
  serialized_end=1496,
)


_HEADERRECORD = _descriptor.Descriptor(
  name='HeaderRecord',
  full_name='wandb_internal.HeaderRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1498,
  serialized_end=1512,
)


_FOOTERRECORD = _descriptor.Descriptor(
  name='FooterRecord',
  full_name='wandb_internal.FooterRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1528,
)


_RUNRECORD = _descriptor.Descriptor(
  name='RunRecord',
  full_name='wandb_internal.RunRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='wandb_internal.RunRecord.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='wandb_internal.RunRecord.entity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='wandb_internal.RunRecord.project', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='wandb_internal.RunRecord.config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='wandb_internal.RunRecord.summary', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_group', full_name='wandb_internal.RunRecord.run_group', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_type', full_name='wandb_internal.RunRecord.job_type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='wandb_internal.RunRecord.display_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notes', full_name='wandb_internal.RunRecord.notes', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='wandb_internal.RunRecord.tags', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settings', full_name='wandb_internal.RunRecord.settings', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sweep_id', full_name='wandb_internal.RunRecord.sweep_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host', full_name='wandb_internal.RunRecord.host', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='starting_step', full_name='wandb_internal.RunRecord.starting_step', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_id', full_name='wandb_internal.RunRecord.storage_id', index=14,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='wandb_internal.RunRecord.start_time', index=15,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resumed', full_name='wandb_internal.RunRecord.resumed', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='wandb_internal.RunRecord.telemetry', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1531,
  serialized_end=2015,
)


_RUNUPDATERESULT = _descriptor.Descriptor(
  name='RunUpdateResult',
  full_name='wandb_internal.RunUpdateResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='wandb_internal.RunUpdateResult.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='wandb_internal.RunUpdateResult.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2017,
  serialized_end=2116,
)


_ERRORINFO = _descriptor.Descriptor(
  name='ErrorInfo',
  full_name='wandb_internal.ErrorInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='wandb_internal.ErrorInfo.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='wandb_internal.ErrorInfo.code', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ERRORINFO_ERRORCODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2119,
  serialized_end=2280,
)


_RUNEXITRECORD = _descriptor.Descriptor(
  name='RunExitRecord',
  full_name='wandb_internal.RunExitRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='wandb_internal.RunExitRecord.exit_code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2282,
  serialized_end=2316,
)


_RUNEXITRESULT = _descriptor.Descriptor(
  name='RunExitResult',
  full_name='wandb_internal.RunExitResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2333,
)


_SETTINGSRECORD = _descriptor.Descriptor(
  name='SettingsRecord',
  full_name='wandb_internal.SettingsRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='wandb_internal.SettingsRecord.item', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2335,
  serialized_end=2395,
)


_SETTINGSITEM = _descriptor.Descriptor(
  name='SettingsItem',
  full_name='wandb_internal.SettingsItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.SettingsItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_json', full_name='wandb_internal.SettingsItem.value_json', index=1,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2397,
  serialized_end=2444,
)


_HISTORYSTEP = _descriptor.Descriptor(
  name='HistoryStep',
  full_name='wandb_internal.HistoryStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='wandb_internal.HistoryStep.num', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2446,
  serialized_end=2472,
)


_HISTORYRECORD = _descriptor.Descriptor(
  name='HistoryRecord',
  full_name='wandb_internal.HistoryRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='wandb_internal.HistoryRecord.item', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='step', full_name='wandb_internal.HistoryRecord.step', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2474,
  serialized_end=2575,
)


_HISTORYITEM = _descriptor.Descriptor(
  name='HistoryItem',
  full_name='wandb_internal.HistoryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.HistoryItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nested_key', full_name='wandb_internal.HistoryItem.nested_key', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_json', full_name='wandb_internal.HistoryItem.value_json', index=2,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2577,
  serialized_end=2643,
)


_HISTORYRESULT = _descriptor.Descriptor(
  name='HistoryResult',
  full_name='wandb_internal.HistoryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2645,
  serialized_end=2660,
)


_OUTPUTRECORD = _descriptor.Descriptor(
  name='OutputRecord',
  full_name='wandb_internal.OutputRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_type', full_name='wandb_internal.OutputRecord.output_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='wandb_internal.OutputRecord.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line', full_name='wandb_internal.OutputRecord.line', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OUTPUTRECORD_OUTPUTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2663,
  serialized_end=2838,
)


_OUTPUTRESULT = _descriptor.Descriptor(
  name='OutputResult',
  full_name='wandb_internal.OutputResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2840,
  serialized_end=2854,
)


_METRICRECORD = _descriptor.Descriptor(
  name='MetricRecord',
  full_name='wandb_internal.MetricRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='wandb_internal.MetricRecord.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='glob_name', full_name='wandb_internal.MetricRecord.glob_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='step_metric', full_name='wandb_internal.MetricRecord.step_metric', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='step_metric_index', full_name='wandb_internal.MetricRecord.step_metric_index', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='wandb_internal.MetricRecord.options', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='wandb_internal.MetricRecord.summary', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='goal', full_name='wandb_internal.MetricRecord.goal', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='_control', full_name='wandb_internal.MetricRecord._control', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _METRICRECORD_METRICGOAL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2857,
  serialized_end=3220,
)


_METRICOPTIONS = _descriptor.Descriptor(
  name='MetricOptions',
  full_name='wandb_internal.MetricOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='step_sync', full_name='wandb_internal.MetricOptions.step_sync', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='wandb_internal.MetricOptions.hidden', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defined', full_name='wandb_internal.MetricOptions.defined', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3222,
  serialized_end=3289,
)


_METRICCONTROL = _descriptor.Descriptor(
  name='MetricControl',
  full_name='wandb_internal.MetricControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='wandb_internal.MetricControl.overwrite', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3291,
  serialized_end=3325,
)


_METRICSUMMARY = _descriptor.Descriptor(
  name='MetricSummary',
  full_name='wandb_internal.MetricSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='wandb_internal.MetricSummary.min', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max', full_name='wandb_internal.MetricSummary.max', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mean', full_name='wandb_internal.MetricSummary.mean', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best', full_name='wandb_internal.MetricSummary.best', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last', full_name='wandb_internal.MetricSummary.last', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='none', full_name='wandb_internal.MetricSummary.none', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='copy', full_name='wandb_internal.MetricSummary.copy', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3327,
  serialized_end=3438,
)


_CONFIGRECORD = _descriptor.Descriptor(
  name='ConfigRecord',
  full_name='wandb_internal.ConfigRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update', full_name='wandb_internal.ConfigRecord.update', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='wandb_internal.ConfigRecord.remove', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3440,
  serialized_end=3542,
)


_CONFIGITEM = _descriptor.Descriptor(
  name='ConfigItem',
  full_name='wandb_internal.ConfigItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.ConfigItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nested_key', full_name='wandb_internal.ConfigItem.nested_key', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_json', full_name='wandb_internal.ConfigItem.value_json', index=2,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3544,
  serialized_end=3609,
)


_CONFIGRESULT = _descriptor.Descriptor(
  name='ConfigResult',
  full_name='wandb_internal.ConfigResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3611,
  serialized_end=3625,
)


_SUMMARYRECORD = _descriptor.Descriptor(
  name='SummaryRecord',
  full_name='wandb_internal.SummaryRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update', full_name='wandb_internal.SummaryRecord.update', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='wandb_internal.SummaryRecord.remove', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3627,
  serialized_end=3732,
)


_SUMMARYITEM = _descriptor.Descriptor(
  name='SummaryItem',
  full_name='wandb_internal.SummaryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.SummaryItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nested_key', full_name='wandb_internal.SummaryItem.nested_key', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_json', full_name='wandb_internal.SummaryItem.value_json', index=2,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3734,
  serialized_end=3800,
)


_SUMMARYRESULT = _descriptor.Descriptor(
  name='SummaryResult',
  full_name='wandb_internal.SummaryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3802,
  serialized_end=3817,
)


_FILESRECORD = _descriptor.Descriptor(
  name='FilesRecord',
  full_name='wandb_internal.FilesRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='wandb_internal.FilesRecord.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3819,
  serialized_end=3874,
)


_FILESITEM = _descriptor.Descriptor(
  name='FilesItem',
  full_name='wandb_internal.FilesItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='wandb_internal.FilesItem.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy', full_name='wandb_internal.FilesItem.policy', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_path', full_name='wandb_internal.FilesItem.external_path', index=2,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FILESITEM_POLICYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3877,
  serialized_end=4021,
)


_STATSRECORD = _descriptor.Descriptor(
  name='StatsRecord',
  full_name='wandb_internal.StatsRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats_type', full_name='wandb_internal.StatsRecord.stats_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='wandb_internal.StatsRecord.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item', full_name='wandb_internal.StatsRecord.item', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATSRECORD_STATSTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4024,
  serialized_end=4209,
)


_STATSITEM = _descriptor.Descriptor(
  name='StatsItem',
  full_name='wandb_internal.StatsItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.StatsItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_json', full_name='wandb_internal.StatsItem.value_json', index=1,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4211,
  serialized_end=4255,
)


_ARTIFACTRECORD = _descriptor.Descriptor(
  name='ArtifactRecord',
  full_name='wandb_internal.ArtifactRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='wandb_internal.ArtifactRecord.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='wandb_internal.ArtifactRecord.project', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity', full_name='wandb_internal.ArtifactRecord.entity', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='wandb_internal.ArtifactRecord.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='wandb_internal.ArtifactRecord.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digest', full_name='wandb_internal.ArtifactRecord.digest', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='wandb_internal.ArtifactRecord.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='wandb_internal.ArtifactRecord.metadata', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_created', full_name='wandb_internal.ArtifactRecord.user_created', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_after_commit', full_name='wandb_internal.ArtifactRecord.use_after_commit', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='wandb_internal.ArtifactRecord.aliases', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manifest', full_name='wandb_internal.ArtifactRecord.manifest', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distributed_id', full_name='wandb_internal.ArtifactRecord.distributed_id', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finalize', full_name='wandb_internal.ArtifactRecord.finalize', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incremental_beta1', full_name='wandb_internal.ArtifactRecord.incremental_beta1', index=14,
      number=100, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4258,
  serialized_end=4592,
)


_ARTIFACTMANIFEST = _descriptor.Descriptor(
  name='ArtifactManifest',
  full_name='wandb_internal.ArtifactManifest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='wandb_internal.ArtifactManifest.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_policy', full_name='wandb_internal.ArtifactManifest.storage_policy', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storage_policy_config', full_name='wandb_internal.ArtifactManifest.storage_policy_config', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contents', full_name='wandb_internal.ArtifactManifest.contents', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4595,
  serialized_end=4783,
)


_ARTIFACTMANIFESTENTRY = _descriptor.Descriptor(
  name='ArtifactManifestEntry',
  full_name='wandb_internal.ArtifactManifestEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='wandb_internal.ArtifactManifestEntry.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='digest', full_name='wandb_internal.ArtifactManifestEntry.digest', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref', full_name='wandb_internal.ArtifactManifestEntry.ref', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='wandb_internal.ArtifactManifestEntry.size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mimetype', full_name='wandb_internal.ArtifactManifestEntry.mimetype', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_path', full_name='wandb_internal.ArtifactManifestEntry.local_path', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='birth_artifact_id', full_name='wandb_internal.ArtifactManifestEntry.birth_artifact_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='wandb_internal.ArtifactManifestEntry.extra', index=7,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4786,
  serialized_end=4973,
)


_EXTRAITEM = _descriptor.Descriptor(
  name='ExtraItem',
  full_name='wandb_internal.ExtraItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.ExtraItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_json', full_name='wandb_internal.ExtraItem.value_json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4975,
  serialized_end=5019,
)


_STORAGEPOLICYCONFIGITEM = _descriptor.Descriptor(
  name='StoragePolicyConfigItem',
  full_name='wandb_internal.StoragePolicyConfigItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.StoragePolicyConfigItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value_json', full_name='wandb_internal.StoragePolicyConfigItem.value_json', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5021,
  serialized_end=5079,
)


_TBRECORD = _descriptor.Descriptor(
  name='TBRecord',
  full_name='wandb_internal.TBRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_dir', full_name='wandb_internal.TBRecord.log_dir', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='save', full_name='wandb_internal.TBRecord.save', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_dir', full_name='wandb_internal.TBRecord.root_dir', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5081,
  serialized_end=5140,
)


_ALERTRECORD = _descriptor.Descriptor(
  name='AlertRecord',
  full_name='wandb_internal.AlertRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='wandb_internal.AlertRecord.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='wandb_internal.AlertRecord.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='level', full_name='wandb_internal.AlertRecord.level', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wait_duration', full_name='wandb_internal.AlertRecord.wait_duration', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5142,
  serialized_end=5222,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='wandb_internal.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_status', full_name='wandb_internal.Request.stop_status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_status', full_name='wandb_internal.Request.network_status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defer', full_name='wandb_internal.Request.defer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_summary', full_name='wandb_internal.Request.get_summary', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='login', full_name='wandb_internal.Request.login', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pause', full_name='wandb_internal.Request.pause', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resume', full_name='wandb_internal.Request.resume', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poll_exit', full_name='wandb_internal.Request.poll_exit', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampled_history', full_name='wandb_internal.Request.sampled_history', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_start', full_name='wandb_internal.Request.run_start', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_version', full_name='wandb_internal.Request.check_version', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_artifact', full_name='wandb_internal.Request.log_artifact', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shutdown', full_name='wandb_internal.Request.shutdown', index=12,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_inject', full_name='wandb_internal.Request.test_inject', index=13,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request_type', full_name='wandb_internal.Request.request_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=5225,
  serialized_end=6028,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='wandb_internal.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stop_status_response', full_name='wandb_internal.Response.stop_status_response', index=0,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_status_response', full_name='wandb_internal.Response.network_status_response', index=1,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='login_response', full_name='wandb_internal.Response.login_response', index=2,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='get_summary_response', full_name='wandb_internal.Response.get_summary_response', index=3,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='poll_exit_response', full_name='wandb_internal.Response.poll_exit_response', index=4,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampled_history_response', full_name='wandb_internal.Response.sampled_history_response', index=5,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_start_response', full_name='wandb_internal.Response.run_start_response', index=6,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check_version_response', full_name='wandb_internal.Response.check_version_response', index=7,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_artifact_response', full_name='wandb_internal.Response.log_artifact_response', index=8,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shutdown_response', full_name='wandb_internal.Response.shutdown_response', index=9,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='test_inject_response', full_name='wandb_internal.Response.test_inject_response', index=10,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response_type', full_name='wandb_internal.Response.response_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6031,
  serialized_end=6803,
)


_DEFERREQUEST = _descriptor.Descriptor(
  name='DeferRequest',
  full_name='wandb_internal.DeferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='wandb_internal.DeferRequest.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEFERREQUEST_DEFERSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6806,
  serialized_end=7017,
)


_PAUSEREQUEST = _descriptor.Descriptor(
  name='PauseRequest',
  full_name='wandb_internal.PauseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7019,
  serialized_end=7033,
)


_RESUMEREQUEST = _descriptor.Descriptor(
  name='ResumeRequest',
  full_name='wandb_internal.ResumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7035,
  serialized_end=7050,
)


_LOGINREQUEST = _descriptor.Descriptor(
  name='LoginRequest',
  full_name='wandb_internal.LoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_key', full_name='wandb_internal.LoginRequest.api_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7052,
  serialized_end=7083,
)


_LOGINRESPONSE = _descriptor.Descriptor(
  name='LoginResponse',
  full_name='wandb_internal.LoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active_entity', full_name='wandb_internal.LoginResponse.active_entity', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7085,
  serialized_end=7123,
)


_GETSUMMARYREQUEST = _descriptor.Descriptor(
  name='GetSummaryRequest',
  full_name='wandb_internal.GetSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7125,
  serialized_end=7144,
)


_GETSUMMARYRESPONSE = _descriptor.Descriptor(
  name='GetSummaryResponse',
  full_name='wandb_internal.GetSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='wandb_internal.GetSummaryResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7146,
  serialized_end=7209,
)


_STOPSTATUSREQUEST = _descriptor.Descriptor(
  name='StopStatusRequest',
  full_name='wandb_internal.StopStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7211,
  serialized_end=7230,
)


_STOPSTATUSRESPONSE = _descriptor.Descriptor(
  name='StopStatusResponse',
  full_name='wandb_internal.StopStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_should_stop', full_name='wandb_internal.StopStatusResponse.run_should_stop', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7232,
  serialized_end=7277,
)


_NETWORKSTATUSREQUEST = _descriptor.Descriptor(
  name='NetworkStatusRequest',
  full_name='wandb_internal.NetworkStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7279,
  serialized_end=7301,
)


_NETWORKSTATUSRESPONSE = _descriptor.Descriptor(
  name='NetworkStatusResponse',
  full_name='wandb_internal.NetworkStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='network_responses', full_name='wandb_internal.NetworkStatusResponse.network_responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7303,
  serialized_end=7383,
)


_HTTPRESPONSE = _descriptor.Descriptor(
  name='HttpResponse',
  full_name='wandb_internal.HttpResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_status_code', full_name='wandb_internal.HttpResponse.http_status_code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http_response_text', full_name='wandb_internal.HttpResponse.http_response_text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7385,
  serialized_end=7453,
)


_POLLEXITREQUEST = _descriptor.Descriptor(
  name='PollExitRequest',
  full_name='wandb_internal.PollExitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7455,
  serialized_end=7472,
)


_POLLEXITRESPONSE = _descriptor.Descriptor(
  name='PollExitResponse',
  full_name='wandb_internal.PollExitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='done', full_name='wandb_internal.PollExitResponse.done', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_result', full_name='wandb_internal.PollExitResponse.exit_result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_counts', full_name='wandb_internal.PollExitResponse.file_counts', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pusher_stats', full_name='wandb_internal.PollExitResponse.pusher_stats', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7475,
  serialized_end=7663,
)


_FILECOUNTS = _descriptor.Descriptor(
  name='FileCounts',
  full_name='wandb_internal.FileCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wandb_count', full_name='wandb_internal.FileCounts.wandb_count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_count', full_name='wandb_internal.FileCounts.media_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact_count', full_name='wandb_internal.FileCounts.artifact_count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='other_count', full_name='wandb_internal.FileCounts.other_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7665,
  serialized_end=7764,
)


_FILEPUSHERSTATS = _descriptor.Descriptor(
  name='FilePusherStats',
  full_name='wandb_internal.FilePusherStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uploaded_bytes', full_name='wandb_internal.FilePusherStats.uploaded_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_bytes', full_name='wandb_internal.FilePusherStats.total_bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deduped_bytes', full_name='wandb_internal.FilePusherStats.deduped_bytes', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7766,
  serialized_end=7851,
)


_SHUTDOWNREQUEST = _descriptor.Descriptor(
  name='ShutdownRequest',
  full_name='wandb_internal.ShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7853,
  serialized_end=7870,
)


_SHUTDOWNRESPONSE = _descriptor.Descriptor(
  name='ShutdownResponse',
  full_name='wandb_internal.ShutdownResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7872,
  serialized_end=7890,
)


_TESTINJECTREQUEST = _descriptor.Descriptor(
  name='TestInjectRequest',
  full_name='wandb_internal.TestInjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='handler_exc', full_name='wandb_internal.TestInjectRequest.handler_exc', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='handler_exit', full_name='wandb_internal.TestInjectRequest.handler_exit', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='handler_abort', full_name='wandb_internal.TestInjectRequest.handler_abort', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_exc', full_name='wandb_internal.TestInjectRequest.sender_exc', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_exit', full_name='wandb_internal.TestInjectRequest.sender_exit', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_abort', full_name='wandb_internal.TestInjectRequest.sender_abort', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='req_exc', full_name='wandb_internal.TestInjectRequest.req_exc', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='req_exit', full_name='wandb_internal.TestInjectRequest.req_exit', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='req_abort', full_name='wandb_internal.TestInjectRequest.req_abort', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resp_exc', full_name='wandb_internal.TestInjectRequest.resp_exc', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resp_exit', full_name='wandb_internal.TestInjectRequest.resp_exit', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resp_abort', full_name='wandb_internal.TestInjectRequest.resp_abort', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_drop', full_name='wandb_internal.TestInjectRequest.msg_drop', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg_hang', full_name='wandb_internal.TestInjectRequest.msg_hang', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7893,
  serialized_end=8188,
)


_TESTINJECTRESPONSE = _descriptor.Descriptor(
  name='TestInjectResponse',
  full_name='wandb_internal.TestInjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8190,
  serialized_end=8210,
)


_SAMPLEDHISTORYREQUEST = _descriptor.Descriptor(
  name='SampledHistoryRequest',
  full_name='wandb_internal.SampledHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8212,
  serialized_end=8235,
)


_SAMPLEDHISTORYITEM = _descriptor.Descriptor(
  name='SampledHistoryItem',
  full_name='wandb_internal.SampledHistoryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='wandb_internal.SampledHistoryItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nested_key', full_name='wandb_internal.SampledHistoryItem.nested_key', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_float', full_name='wandb_internal.SampledHistoryItem.values_float', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_int', full_name='wandb_internal.SampledHistoryItem.values_int', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8237,
  serialized_end=8332,
)


_SAMPLEDHISTORYRESPONSE = _descriptor.Descriptor(
  name='SampledHistoryResponse',
  full_name='wandb_internal.SampledHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='wandb_internal.SampledHistoryResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8334,
  serialized_end=8408,
)


_RUNSTARTREQUEST = _descriptor.Descriptor(
  name='RunStartRequest',
  full_name='wandb_internal.RunStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='wandb_internal.RunStartRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8410,
  serialized_end=8467,
)


_RUNSTARTRESPONSE = _descriptor.Descriptor(
  name='RunStartResponse',
  full_name='wandb_internal.RunStartResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8469,
  serialized_end=8487,
)


_CHECKVERSIONREQUEST = _descriptor.Descriptor(
  name='CheckVersionRequest',
  full_name='wandb_internal.CheckVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_version', full_name='wandb_internal.CheckVersionRequest.current_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8489,
  serialized_end=8535,
)


_CHECKVERSIONRESPONSE = _descriptor.Descriptor(
  name='CheckVersionResponse',
  full_name='wandb_internal.CheckVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upgrade_message', full_name='wandb_internal.CheckVersionResponse.upgrade_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yank_message', full_name='wandb_internal.CheckVersionResponse.yank_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_message', full_name='wandb_internal.CheckVersionResponse.delete_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8537,
  serialized_end=8630,
)


_LOGARTIFACTREQUEST = _descriptor.Descriptor(
  name='LogArtifactRequest',
  full_name='wandb_internal.LogArtifactRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact', full_name='wandb_internal.LogArtifactRequest.artifact', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8632,
  serialized_end=8702,
)


_LOGARTIFACTRESPONSE = _descriptor.Descriptor(
  name='LogArtifactResponse',
  full_name='wandb_internal.LogArtifactResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifact_id', full_name='wandb_internal.LogArtifactResponse.artifact_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='wandb_internal.LogArtifactResponse.error_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8704,
  serialized_end=8769,
)

_RECORD.fields_by_name['history'].message_type = _HISTORYRECORD
_RECORD.fields_by_name['summary'].message_type = _SUMMARYRECORD
_RECORD.fields_by_name['output'].message_type = _OUTPUTRECORD
_RECORD.fields_by_name['config'].message_type = _CONFIGRECORD
_RECORD.fields_by_name['files'].message_type = _FILESRECORD
_RECORD.fields_by_name['stats'].message_type = _STATSRECORD
_RECORD.fields_by_name['artifact'].message_type = _ARTIFACTRECORD
_RECORD.fields_by_name['tbrecord'].message_type = _TBRECORD
_RECORD.fields_by_name['alert'].message_type = _ALERTRECORD
_RECORD.fields_by_name['telemetry'].message_type = wandb_dot_proto_dot_wandb__telemetry__pb2._TELEMETRYRECORD
_RECORD.fields_by_name['metric'].message_type = _METRICRECORD
_RECORD.fields_by_name['run'].message_type = _RUNRECORD
_RECORD.fields_by_name['exit'].message_type = _RUNEXITRECORD
_RECORD.fields_by_name['final'].message_type = _FINALRECORD
_RECORD.fields_by_name['header'].message_type = _HEADERRECORD
_RECORD.fields_by_name['footer'].message_type = _FOOTERRECORD
_RECORD.fields_by_name['request'].message_type = _REQUEST
_RECORD.fields_by_name['control'].message_type = _CONTROL
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['history'])
_RECORD.fields_by_name['history'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['summary'])
_RECORD.fields_by_name['summary'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['output'])
_RECORD.fields_by_name['output'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['config'])
_RECORD.fields_by_name['config'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['files'])
_RECORD.fields_by_name['files'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['stats'])
_RECORD.fields_by_name['stats'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['artifact'])
_RECORD.fields_by_name['artifact'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['tbrecord'])
_RECORD.fields_by_name['tbrecord'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['alert'])
_RECORD.fields_by_name['alert'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['telemetry'])
_RECORD.fields_by_name['telemetry'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['metric'])
_RECORD.fields_by_name['metric'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['run'])
_RECORD.fields_by_name['run'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['exit'])
_RECORD.fields_by_name['exit'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['final'])
_RECORD.fields_by_name['final'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['header'])
_RECORD.fields_by_name['header'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['footer'])
_RECORD.fields_by_name['footer'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RECORD.oneofs_by_name['record_type'].fields.append(
  _RECORD.fields_by_name['request'])
_RECORD.fields_by_name['request'].containing_oneof = _RECORD.oneofs_by_name['record_type']
_RESULT.fields_by_name['run_result'].message_type = _RUNUPDATERESULT
_RESULT.fields_by_name['exit_result'].message_type = _RUNEXITRESULT
_RESULT.fields_by_name['log_result'].message_type = _HISTORYRESULT
_RESULT.fields_by_name['summary_result'].message_type = _SUMMARYRESULT
_RESULT.fields_by_name['output_result'].message_type = _OUTPUTRESULT
_RESULT.fields_by_name['config_result'].message_type = _CONFIGRESULT
_RESULT.fields_by_name['response'].message_type = _RESPONSE
_RESULT.oneofs_by_name['result_type'].fields.append(
  _RESULT.fields_by_name['run_result'])
_RESULT.fields_by_name['run_result'].containing_oneof = _RESULT.oneofs_by_name['result_type']
_RESULT.oneofs_by_name['result_type'].fields.append(
  _RESULT.fields_by_name['exit_result'])
_RESULT.fields_by_name['exit_result'].containing_oneof = _RESULT.oneofs_by_name['result_type']
_RESULT.oneofs_by_name['result_type'].fields.append(
  _RESULT.fields_by_name['log_result'])
_RESULT.fields_by_name['log_result'].containing_oneof = _RESULT.oneofs_by_name['result_type']
_RESULT.oneofs_by_name['result_type'].fields.append(
  _RESULT.fields_by_name['summary_result'])
_RESULT.fields_by_name['summary_result'].containing_oneof = _RESULT.oneofs_by_name['result_type']
_RESULT.oneofs_by_name['result_type'].fields.append(
  _RESULT.fields_by_name['output_result'])
_RESULT.fields_by_name['output_result'].containing_oneof = _RESULT.oneofs_by_name['result_type']
_RESULT.oneofs_by_name['result_type'].fields.append(
  _RESULT.fields_by_name['config_result'])
_RESULT.fields_by_name['config_result'].containing_oneof = _RESULT.oneofs_by_name['result_type']
_RESULT.oneofs_by_name['result_type'].fields.append(
  _RESULT.fields_by_name['response'])
_RESULT.fields_by_name['response'].containing_oneof = _RESULT.oneofs_by_name['result_type']
_RUNRECORD.fields_by_name['config'].message_type = _CONFIGRECORD
_RUNRECORD.fields_by_name['summary'].message_type = _SUMMARYRECORD
_RUNRECORD.fields_by_name['settings'].message_type = _SETTINGSRECORD
_RUNRECORD.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RUNRECORD.fields_by_name['telemetry'].message_type = wandb_dot_proto_dot_wandb__telemetry__pb2._TELEMETRYRECORD
_RUNUPDATERESULT.fields_by_name['run'].message_type = _RUNRECORD
_RUNUPDATERESULT.fields_by_name['error'].message_type = _ERRORINFO
_ERRORINFO.fields_by_name['code'].enum_type = _ERRORINFO_ERRORCODE
_ERRORINFO_ERRORCODE.containing_type = _ERRORINFO
_SETTINGSRECORD.fields_by_name['item'].message_type = _SETTINGSITEM
_HISTORYRECORD.fields_by_name['item'].message_type = _HISTORYITEM
_HISTORYRECORD.fields_by_name['step'].message_type = _HISTORYSTEP
_OUTPUTRECORD.fields_by_name['output_type'].enum_type = _OUTPUTRECORD_OUTPUTTYPE
_OUTPUTRECORD.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OUTPUTRECORD_OUTPUTTYPE.containing_type = _OUTPUTRECORD
_METRICRECORD.fields_by_name['options'].message_type = _METRICOPTIONS
_METRICRECORD.fields_by_name['summary'].message_type = _METRICSUMMARY
_METRICRECORD.fields_by_name['goal'].enum_type = _METRICRECORD_METRICGOAL
_METRICRECORD.fields_by_name['_control'].message_type = _METRICCONTROL
_METRICRECORD_METRICGOAL.containing_type = _METRICRECORD
_CONFIGRECORD.fields_by_name['update'].message_type = _CONFIGITEM
_CONFIGRECORD.fields_by_name['remove'].message_type = _CONFIGITEM
_SUMMARYRECORD.fields_by_name['update'].message_type = _SUMMARYITEM
_SUMMARYRECORD.fields_by_name['remove'].message_type = _SUMMARYITEM
_FILESRECORD.fields_by_name['files'].message_type = _FILESITEM
_FILESITEM.fields_by_name['policy'].enum_type = _FILESITEM_POLICYTYPE
_FILESITEM_POLICYTYPE.containing_type = _FILESITEM
_STATSRECORD.fields_by_name['stats_type'].enum_type = _STATSRECORD_STATSTYPE
_STATSRECORD.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATSRECORD.fields_by_name['item'].message_type = _STATSITEM
_STATSRECORD_STATSTYPE.containing_type = _STATSRECORD
_ARTIFACTRECORD.fields_by_name['manifest'].message_type = _ARTIFACTMANIFEST
_ARTIFACTMANIFEST.fields_by_name['storage_policy_config'].message_type = _STORAGEPOLICYCONFIGITEM
_ARTIFACTMANIFEST.fields_by_name['contents'].message_type = _ARTIFACTMANIFESTENTRY
_ARTIFACTMANIFESTENTRY.fields_by_name['extra'].message_type = _EXTRAITEM
_REQUEST.fields_by_name['stop_status'].message_type = _STOPSTATUSREQUEST
_REQUEST.fields_by_name['network_status'].message_type = _NETWORKSTATUSREQUEST
_REQUEST.fields_by_name['defer'].message_type = _DEFERREQUEST
_REQUEST.fields_by_name['get_summary'].message_type = _GETSUMMARYREQUEST
_REQUEST.fields_by_name['login'].message_type = _LOGINREQUEST
_REQUEST.fields_by_name['pause'].message_type = _PAUSEREQUEST
_REQUEST.fields_by_name['resume'].message_type = _RESUMEREQUEST
_REQUEST.fields_by_name['poll_exit'].message_type = _POLLEXITREQUEST
_REQUEST.fields_by_name['sampled_history'].message_type = _SAMPLEDHISTORYREQUEST
_REQUEST.fields_by_name['run_start'].message_type = _RUNSTARTREQUEST
_REQUEST.fields_by_name['check_version'].message_type = _CHECKVERSIONREQUEST
_REQUEST.fields_by_name['log_artifact'].message_type = _LOGARTIFACTREQUEST
_REQUEST.fields_by_name['shutdown'].message_type = _SHUTDOWNREQUEST
_REQUEST.fields_by_name['test_inject'].message_type = _TESTINJECTREQUEST
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['stop_status'])
_REQUEST.fields_by_name['stop_status'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['network_status'])
_REQUEST.fields_by_name['network_status'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['defer'])
_REQUEST.fields_by_name['defer'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['get_summary'])
_REQUEST.fields_by_name['get_summary'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['login'])
_REQUEST.fields_by_name['login'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['pause'])
_REQUEST.fields_by_name['pause'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['resume'])
_REQUEST.fields_by_name['resume'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['poll_exit'])
_REQUEST.fields_by_name['poll_exit'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['sampled_history'])
_REQUEST.fields_by_name['sampled_history'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['run_start'])
_REQUEST.fields_by_name['run_start'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['check_version'])
_REQUEST.fields_by_name['check_version'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['log_artifact'])
_REQUEST.fields_by_name['log_artifact'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['shutdown'])
_REQUEST.fields_by_name['shutdown'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_REQUEST.oneofs_by_name['request_type'].fields.append(
  _REQUEST.fields_by_name['test_inject'])
_REQUEST.fields_by_name['test_inject'].containing_oneof = _REQUEST.oneofs_by_name['request_type']
_RESPONSE.fields_by_name['stop_status_response'].message_type = _STOPSTATUSRESPONSE
_RESPONSE.fields_by_name['network_status_response'].message_type = _NETWORKSTATUSRESPONSE
_RESPONSE.fields_by_name['login_response'].message_type = _LOGINRESPONSE
_RESPONSE.fields_by_name['get_summary_response'].message_type = _GETSUMMARYRESPONSE
_RESPONSE.fields_by_name['poll_exit_response'].message_type = _POLLEXITRESPONSE
_RESPONSE.fields_by_name['sampled_history_response'].message_type = _SAMPLEDHISTORYRESPONSE
_RESPONSE.fields_by_name['run_start_response'].message_type = _RUNSTARTRESPONSE
_RESPONSE.fields_by_name['check_version_response'].message_type = _CHECKVERSIONRESPONSE
_RESPONSE.fields_by_name['log_artifact_response'].message_type = _LOGARTIFACTRESPONSE
_RESPONSE.fields_by_name['shutdown_response'].message_type = _SHUTDOWNRESPONSE
_RESPONSE.fields_by_name['test_inject_response'].message_type = _TESTINJECTRESPONSE
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['stop_status_response'])
_RESPONSE.fields_by_name['stop_status_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['network_status_response'])
_RESPONSE.fields_by_name['network_status_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['login_response'])
_RESPONSE.fields_by_name['login_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['get_summary_response'])
_RESPONSE.fields_by_name['get_summary_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['poll_exit_response'])
_RESPONSE.fields_by_name['poll_exit_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['sampled_history_response'])
_RESPONSE.fields_by_name['sampled_history_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['run_start_response'])
_RESPONSE.fields_by_name['run_start_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['check_version_response'])
_RESPONSE.fields_by_name['check_version_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['log_artifact_response'])
_RESPONSE.fields_by_name['log_artifact_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['shutdown_response'])
_RESPONSE.fields_by_name['shutdown_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_RESPONSE.oneofs_by_name['response_type'].fields.append(
  _RESPONSE.fields_by_name['test_inject_response'])
_RESPONSE.fields_by_name['test_inject_response'].containing_oneof = _RESPONSE.oneofs_by_name['response_type']
_DEFERREQUEST.fields_by_name['state'].enum_type = _DEFERREQUEST_DEFERSTATE
_DEFERREQUEST_DEFERSTATE.containing_type = _DEFERREQUEST
_GETSUMMARYRESPONSE.fields_by_name['item'].message_type = _SUMMARYITEM
_NETWORKSTATUSRESPONSE.fields_by_name['network_responses'].message_type = _HTTPRESPONSE
_POLLEXITRESPONSE.fields_by_name['exit_result'].message_type = _RUNEXITRESULT
_POLLEXITRESPONSE.fields_by_name['file_counts'].message_type = _FILECOUNTS
_POLLEXITRESPONSE.fields_by_name['pusher_stats'].message_type = _FILEPUSHERSTATS
_SAMPLEDHISTORYRESPONSE.fields_by_name['item'].message_type = _SAMPLEDHISTORYITEM
_RUNSTARTREQUEST.fields_by_name['run'].message_type = _RUNRECORD
_LOGARTIFACTREQUEST.fields_by_name['artifact'].message_type = _ARTIFACTRECORD
DESCRIPTOR.message_types_by_name['Record'] = _RECORD
DESCRIPTOR.message_types_by_name['Control'] = _CONTROL
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['FinalRecord'] = _FINALRECORD
DESCRIPTOR.message_types_by_name['HeaderRecord'] = _HEADERRECORD
DESCRIPTOR.message_types_by_name['FooterRecord'] = _FOOTERRECORD
DESCRIPTOR.message_types_by_name['RunRecord'] = _RUNRECORD
DESCRIPTOR.message_types_by_name['RunUpdateResult'] = _RUNUPDATERESULT
DESCRIPTOR.message_types_by_name['ErrorInfo'] = _ERRORINFO
DESCRIPTOR.message_types_by_name['RunExitRecord'] = _RUNEXITRECORD
DESCRIPTOR.message_types_by_name['RunExitResult'] = _RUNEXITRESULT
DESCRIPTOR.message_types_by_name['SettingsRecord'] = _SETTINGSRECORD
DESCRIPTOR.message_types_by_name['SettingsItem'] = _SETTINGSITEM
DESCRIPTOR.message_types_by_name['HistoryStep'] = _HISTORYSTEP
DESCRIPTOR.message_types_by_name['HistoryRecord'] = _HISTORYRECORD
DESCRIPTOR.message_types_by_name['HistoryItem'] = _HISTORYITEM
DESCRIPTOR.message_types_by_name['HistoryResult'] = _HISTORYRESULT
DESCRIPTOR.message_types_by_name['OutputRecord'] = _OUTPUTRECORD
DESCRIPTOR.message_types_by_name['OutputResult'] = _OUTPUTRESULT
DESCRIPTOR.message_types_by_name['MetricRecord'] = _METRICRECORD
DESCRIPTOR.message_types_by_name['MetricOptions'] = _METRICOPTIONS
DESCRIPTOR.message_types_by_name['MetricControl'] = _METRICCONTROL
DESCRIPTOR.message_types_by_name['MetricSummary'] = _METRICSUMMARY
DESCRIPTOR.message_types_by_name['ConfigRecord'] = _CONFIGRECORD
DESCRIPTOR.message_types_by_name['ConfigItem'] = _CONFIGITEM
DESCRIPTOR.message_types_by_name['ConfigResult'] = _CONFIGRESULT
DESCRIPTOR.message_types_by_name['SummaryRecord'] = _SUMMARYRECORD
DESCRIPTOR.message_types_by_name['SummaryItem'] = _SUMMARYITEM
DESCRIPTOR.message_types_by_name['SummaryResult'] = _SUMMARYRESULT
DESCRIPTOR.message_types_by_name['FilesRecord'] = _FILESRECORD
DESCRIPTOR.message_types_by_name['FilesItem'] = _FILESITEM
DESCRIPTOR.message_types_by_name['StatsRecord'] = _STATSRECORD
DESCRIPTOR.message_types_by_name['StatsItem'] = _STATSITEM
DESCRIPTOR.message_types_by_name['ArtifactRecord'] = _ARTIFACTRECORD
DESCRIPTOR.message_types_by_name['ArtifactManifest'] = _ARTIFACTMANIFEST
DESCRIPTOR.message_types_by_name['ArtifactManifestEntry'] = _ARTIFACTMANIFESTENTRY
DESCRIPTOR.message_types_by_name['ExtraItem'] = _EXTRAITEM
DESCRIPTOR.message_types_by_name['StoragePolicyConfigItem'] = _STORAGEPOLICYCONFIGITEM
DESCRIPTOR.message_types_by_name['TBRecord'] = _TBRECORD
DESCRIPTOR.message_types_by_name['AlertRecord'] = _ALERTRECORD
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['DeferRequest'] = _DEFERREQUEST
DESCRIPTOR.message_types_by_name['PauseRequest'] = _PAUSEREQUEST
DESCRIPTOR.message_types_by_name['ResumeRequest'] = _RESUMEREQUEST
DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['LoginResponse'] = _LOGINRESPONSE
DESCRIPTOR.message_types_by_name['GetSummaryRequest'] = _GETSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['GetSummaryResponse'] = _GETSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['StopStatusRequest'] = _STOPSTATUSREQUEST
DESCRIPTOR.message_types_by_name['StopStatusResponse'] = _STOPSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['NetworkStatusRequest'] = _NETWORKSTATUSREQUEST
DESCRIPTOR.message_types_by_name['NetworkStatusResponse'] = _NETWORKSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['HttpResponse'] = _HTTPRESPONSE
DESCRIPTOR.message_types_by_name['PollExitRequest'] = _POLLEXITREQUEST
DESCRIPTOR.message_types_by_name['PollExitResponse'] = _POLLEXITRESPONSE
DESCRIPTOR.message_types_by_name['FileCounts'] = _FILECOUNTS
DESCRIPTOR.message_types_by_name['FilePusherStats'] = _FILEPUSHERSTATS
DESCRIPTOR.message_types_by_name['ShutdownRequest'] = _SHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['ShutdownResponse'] = _SHUTDOWNRESPONSE
DESCRIPTOR.message_types_by_name['TestInjectRequest'] = _TESTINJECTREQUEST
DESCRIPTOR.message_types_by_name['TestInjectResponse'] = _TESTINJECTRESPONSE
DESCRIPTOR.message_types_by_name['SampledHistoryRequest'] = _SAMPLEDHISTORYREQUEST
DESCRIPTOR.message_types_by_name['SampledHistoryItem'] = _SAMPLEDHISTORYITEM
DESCRIPTOR.message_types_by_name['SampledHistoryResponse'] = _SAMPLEDHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['RunStartRequest'] = _RUNSTARTREQUEST
DESCRIPTOR.message_types_by_name['RunStartResponse'] = _RUNSTARTRESPONSE
DESCRIPTOR.message_types_by_name['CheckVersionRequest'] = _CHECKVERSIONREQUEST
DESCRIPTOR.message_types_by_name['CheckVersionResponse'] = _CHECKVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['LogArtifactRequest'] = _LOGARTIFACTREQUEST
DESCRIPTOR.message_types_by_name['LogArtifactResponse'] = _LOGARTIFACTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Record = _reflection.GeneratedProtocolMessageType('Record', (_message.Message,), {
  'DESCRIPTOR' : _RECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.Record)
  })
_sym_db.RegisterMessage(Record)

Control = _reflection.GeneratedProtocolMessageType('Control', (_message.Message,), {
  'DESCRIPTOR' : _CONTROL,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.Control)
  })
_sym_db.RegisterMessage(Control)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.Result)
  })
_sym_db.RegisterMessage(Result)

FinalRecord = _reflection.GeneratedProtocolMessageType('FinalRecord', (_message.Message,), {
  'DESCRIPTOR' : _FINALRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.FinalRecord)
  })
_sym_db.RegisterMessage(FinalRecord)

HeaderRecord = _reflection.GeneratedProtocolMessageType('HeaderRecord', (_message.Message,), {
  'DESCRIPTOR' : _HEADERRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.HeaderRecord)
  })
_sym_db.RegisterMessage(HeaderRecord)

FooterRecord = _reflection.GeneratedProtocolMessageType('FooterRecord', (_message.Message,), {
  'DESCRIPTOR' : _FOOTERRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.FooterRecord)
  })
_sym_db.RegisterMessage(FooterRecord)

RunRecord = _reflection.GeneratedProtocolMessageType('RunRecord', (_message.Message,), {
  'DESCRIPTOR' : _RUNRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.RunRecord)
  })
_sym_db.RegisterMessage(RunRecord)

RunUpdateResult = _reflection.GeneratedProtocolMessageType('RunUpdateResult', (_message.Message,), {
  'DESCRIPTOR' : _RUNUPDATERESULT,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.RunUpdateResult)
  })
_sym_db.RegisterMessage(RunUpdateResult)

ErrorInfo = _reflection.GeneratedProtocolMessageType('ErrorInfo', (_message.Message,), {
  'DESCRIPTOR' : _ERRORINFO,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ErrorInfo)
  })
_sym_db.RegisterMessage(ErrorInfo)

RunExitRecord = _reflection.GeneratedProtocolMessageType('RunExitRecord', (_message.Message,), {
  'DESCRIPTOR' : _RUNEXITRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.RunExitRecord)
  })
_sym_db.RegisterMessage(RunExitRecord)

RunExitResult = _reflection.GeneratedProtocolMessageType('RunExitResult', (_message.Message,), {
  'DESCRIPTOR' : _RUNEXITRESULT,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.RunExitResult)
  })
_sym_db.RegisterMessage(RunExitResult)

SettingsRecord = _reflection.GeneratedProtocolMessageType('SettingsRecord', (_message.Message,), {
  'DESCRIPTOR' : _SETTINGSRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SettingsRecord)
  })
_sym_db.RegisterMessage(SettingsRecord)

SettingsItem = _reflection.GeneratedProtocolMessageType('SettingsItem', (_message.Message,), {
  'DESCRIPTOR' : _SETTINGSITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SettingsItem)
  })
_sym_db.RegisterMessage(SettingsItem)

HistoryStep = _reflection.GeneratedProtocolMessageType('HistoryStep', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYSTEP,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.HistoryStep)
  })
_sym_db.RegisterMessage(HistoryStep)

HistoryRecord = _reflection.GeneratedProtocolMessageType('HistoryRecord', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.HistoryRecord)
  })
_sym_db.RegisterMessage(HistoryRecord)

HistoryItem = _reflection.GeneratedProtocolMessageType('HistoryItem', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.HistoryItem)
  })
_sym_db.RegisterMessage(HistoryItem)

HistoryResult = _reflection.GeneratedProtocolMessageType('HistoryResult', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYRESULT,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.HistoryResult)
  })
_sym_db.RegisterMessage(HistoryResult)

OutputRecord = _reflection.GeneratedProtocolMessageType('OutputRecord', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.OutputRecord)
  })
_sym_db.RegisterMessage(OutputRecord)

OutputResult = _reflection.GeneratedProtocolMessageType('OutputResult', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUTRESULT,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.OutputResult)
  })
_sym_db.RegisterMessage(OutputResult)

MetricRecord = _reflection.GeneratedProtocolMessageType('MetricRecord', (_message.Message,), {
  'DESCRIPTOR' : _METRICRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.MetricRecord)
  })
_sym_db.RegisterMessage(MetricRecord)

MetricOptions = _reflection.GeneratedProtocolMessageType('MetricOptions', (_message.Message,), {
  'DESCRIPTOR' : _METRICOPTIONS,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.MetricOptions)
  })
_sym_db.RegisterMessage(MetricOptions)

MetricControl = _reflection.GeneratedProtocolMessageType('MetricControl', (_message.Message,), {
  'DESCRIPTOR' : _METRICCONTROL,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.MetricControl)
  })
_sym_db.RegisterMessage(MetricControl)

MetricSummary = _reflection.GeneratedProtocolMessageType('MetricSummary', (_message.Message,), {
  'DESCRIPTOR' : _METRICSUMMARY,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.MetricSummary)
  })
_sym_db.RegisterMessage(MetricSummary)

ConfigRecord = _reflection.GeneratedProtocolMessageType('ConfigRecord', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ConfigRecord)
  })
_sym_db.RegisterMessage(ConfigRecord)

ConfigItem = _reflection.GeneratedProtocolMessageType('ConfigItem', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ConfigItem)
  })
_sym_db.RegisterMessage(ConfigItem)

ConfigResult = _reflection.GeneratedProtocolMessageType('ConfigResult', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGRESULT,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ConfigResult)
  })
_sym_db.RegisterMessage(ConfigResult)

SummaryRecord = _reflection.GeneratedProtocolMessageType('SummaryRecord', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SummaryRecord)
  })
_sym_db.RegisterMessage(SummaryRecord)

SummaryItem = _reflection.GeneratedProtocolMessageType('SummaryItem', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SummaryItem)
  })
_sym_db.RegisterMessage(SummaryItem)

SummaryResult = _reflection.GeneratedProtocolMessageType('SummaryResult', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYRESULT,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SummaryResult)
  })
_sym_db.RegisterMessage(SummaryResult)

FilesRecord = _reflection.GeneratedProtocolMessageType('FilesRecord', (_message.Message,), {
  'DESCRIPTOR' : _FILESRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.FilesRecord)
  })
_sym_db.RegisterMessage(FilesRecord)

FilesItem = _reflection.GeneratedProtocolMessageType('FilesItem', (_message.Message,), {
  'DESCRIPTOR' : _FILESITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.FilesItem)
  })
_sym_db.RegisterMessage(FilesItem)

StatsRecord = _reflection.GeneratedProtocolMessageType('StatsRecord', (_message.Message,), {
  'DESCRIPTOR' : _STATSRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.StatsRecord)
  })
_sym_db.RegisterMessage(StatsRecord)

StatsItem = _reflection.GeneratedProtocolMessageType('StatsItem', (_message.Message,), {
  'DESCRIPTOR' : _STATSITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.StatsItem)
  })
_sym_db.RegisterMessage(StatsItem)

ArtifactRecord = _reflection.GeneratedProtocolMessageType('ArtifactRecord', (_message.Message,), {
  'DESCRIPTOR' : _ARTIFACTRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ArtifactRecord)
  })
_sym_db.RegisterMessage(ArtifactRecord)

ArtifactManifest = _reflection.GeneratedProtocolMessageType('ArtifactManifest', (_message.Message,), {
  'DESCRIPTOR' : _ARTIFACTMANIFEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ArtifactManifest)
  })
_sym_db.RegisterMessage(ArtifactManifest)

ArtifactManifestEntry = _reflection.GeneratedProtocolMessageType('ArtifactManifestEntry', (_message.Message,), {
  'DESCRIPTOR' : _ARTIFACTMANIFESTENTRY,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ArtifactManifestEntry)
  })
_sym_db.RegisterMessage(ArtifactManifestEntry)

ExtraItem = _reflection.GeneratedProtocolMessageType('ExtraItem', (_message.Message,), {
  'DESCRIPTOR' : _EXTRAITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ExtraItem)
  })
_sym_db.RegisterMessage(ExtraItem)

StoragePolicyConfigItem = _reflection.GeneratedProtocolMessageType('StoragePolicyConfigItem', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEPOLICYCONFIGITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.StoragePolicyConfigItem)
  })
_sym_db.RegisterMessage(StoragePolicyConfigItem)

TBRecord = _reflection.GeneratedProtocolMessageType('TBRecord', (_message.Message,), {
  'DESCRIPTOR' : _TBRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.TBRecord)
  })
_sym_db.RegisterMessage(TBRecord)

AlertRecord = _reflection.GeneratedProtocolMessageType('AlertRecord', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRECORD,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.AlertRecord)
  })
_sym_db.RegisterMessage(AlertRecord)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.Request)
  })
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.Response)
  })
_sym_db.RegisterMessage(Response)

DeferRequest = _reflection.GeneratedProtocolMessageType('DeferRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEFERREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.DeferRequest)
  })
_sym_db.RegisterMessage(DeferRequest)

PauseRequest = _reflection.GeneratedProtocolMessageType('PauseRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.PauseRequest)
  })
_sym_db.RegisterMessage(PauseRequest)

ResumeRequest = _reflection.GeneratedProtocolMessageType('ResumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ResumeRequest)
  })
_sym_db.RegisterMessage(ResumeRequest)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.LoginRequest)
  })
_sym_db.RegisterMessage(LoginRequest)

LoginResponse = _reflection.GeneratedProtocolMessageType('LoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.LoginResponse)
  })
_sym_db.RegisterMessage(LoginResponse)

GetSummaryRequest = _reflection.GeneratedProtocolMessageType('GetSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUMMARYREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.GetSummaryRequest)
  })
_sym_db.RegisterMessage(GetSummaryRequest)

GetSummaryResponse = _reflection.GeneratedProtocolMessageType('GetSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSUMMARYRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.GetSummaryResponse)
  })
_sym_db.RegisterMessage(GetSummaryResponse)

StopStatusRequest = _reflection.GeneratedProtocolMessageType('StopStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPSTATUSREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.StopStatusRequest)
  })
_sym_db.RegisterMessage(StopStatusRequest)

StopStatusResponse = _reflection.GeneratedProtocolMessageType('StopStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPSTATUSRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.StopStatusResponse)
  })
_sym_db.RegisterMessage(StopStatusResponse)

NetworkStatusRequest = _reflection.GeneratedProtocolMessageType('NetworkStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKSTATUSREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.NetworkStatusRequest)
  })
_sym_db.RegisterMessage(NetworkStatusRequest)

NetworkStatusResponse = _reflection.GeneratedProtocolMessageType('NetworkStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKSTATUSRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.NetworkStatusResponse)
  })
_sym_db.RegisterMessage(NetworkStatusResponse)

HttpResponse = _reflection.GeneratedProtocolMessageType('HttpResponse', (_message.Message,), {
  'DESCRIPTOR' : _HTTPRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.HttpResponse)
  })
_sym_db.RegisterMessage(HttpResponse)

PollExitRequest = _reflection.GeneratedProtocolMessageType('PollExitRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLLEXITREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.PollExitRequest)
  })
_sym_db.RegisterMessage(PollExitRequest)

PollExitResponse = _reflection.GeneratedProtocolMessageType('PollExitResponse', (_message.Message,), {
  'DESCRIPTOR' : _POLLEXITRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.PollExitResponse)
  })
_sym_db.RegisterMessage(PollExitResponse)

FileCounts = _reflection.GeneratedProtocolMessageType('FileCounts', (_message.Message,), {
  'DESCRIPTOR' : _FILECOUNTS,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.FileCounts)
  })
_sym_db.RegisterMessage(FileCounts)

FilePusherStats = _reflection.GeneratedProtocolMessageType('FilePusherStats', (_message.Message,), {
  'DESCRIPTOR' : _FILEPUSHERSTATS,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.FilePusherStats)
  })
_sym_db.RegisterMessage(FilePusherStats)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

TestInjectRequest = _reflection.GeneratedProtocolMessageType('TestInjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTINJECTREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.TestInjectRequest)
  })
_sym_db.RegisterMessage(TestInjectRequest)

TestInjectResponse = _reflection.GeneratedProtocolMessageType('TestInjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTINJECTRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.TestInjectResponse)
  })
_sym_db.RegisterMessage(TestInjectResponse)

SampledHistoryRequest = _reflection.GeneratedProtocolMessageType('SampledHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLEDHISTORYREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SampledHistoryRequest)
  })
_sym_db.RegisterMessage(SampledHistoryRequest)

SampledHistoryItem = _reflection.GeneratedProtocolMessageType('SampledHistoryItem', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLEDHISTORYITEM,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SampledHistoryItem)
  })
_sym_db.RegisterMessage(SampledHistoryItem)

SampledHistoryResponse = _reflection.GeneratedProtocolMessageType('SampledHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAMPLEDHISTORYRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.SampledHistoryResponse)
  })
_sym_db.RegisterMessage(SampledHistoryResponse)

RunStartRequest = _reflection.GeneratedProtocolMessageType('RunStartRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNSTARTREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.RunStartRequest)
  })
_sym_db.RegisterMessage(RunStartRequest)

RunStartResponse = _reflection.GeneratedProtocolMessageType('RunStartResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNSTARTRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.RunStartResponse)
  })
_sym_db.RegisterMessage(RunStartResponse)

CheckVersionRequest = _reflection.GeneratedProtocolMessageType('CheckVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKVERSIONREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.CheckVersionRequest)
  })
_sym_db.RegisterMessage(CheckVersionRequest)

CheckVersionResponse = _reflection.GeneratedProtocolMessageType('CheckVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKVERSIONRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.CheckVersionResponse)
  })
_sym_db.RegisterMessage(CheckVersionResponse)

LogArtifactRequest = _reflection.GeneratedProtocolMessageType('LogArtifactRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGARTIFACTREQUEST,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.LogArtifactRequest)
  })
_sym_db.RegisterMessage(LogArtifactRequest)

LogArtifactResponse = _reflection.GeneratedProtocolMessageType('LogArtifactResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGARTIFACTRESPONSE,
  '__module__' : 'wandb.proto.wandb_internal_pb2'
  # @@protoc_insertion_point(class_scope:wandb_internal.LogArtifactResponse)
  })
_sym_db.RegisterMessage(LogArtifactResponse)


# @@protoc_insertion_point(module_scope)
